@@ -173,9 +173,13 @@ class ExerciseView(SelectWinBase):
         do_sg = True
         if len(page[0]) > 0 and isinstance(page[0][0], frontpage.LinkList):
             count = 0
-            for p in page[0]:
-                if len(p):
-                    count += len(p[0])
+            for column in page:
+                assert isinstance(column, frontpage.Column)
+                for linklist in column:
+                    assert isinstance(linklist, (frontpage.LinkList,
+                                                 frontpage.Paragraph))
+                    if isinstance(linklist, frontpage.LinkList):
+                        count += len(linklist)
             if count > 80:
                 do_sg = False
         for column in page:
@@ -188,6 +192,7 @@ class ExerciseView(SelectWinBase):
             for sect_id, linklist in enumerate(column):
                 if isinstance(linklist, frontpage.Paragraph):
                     label = gtk.Label(linklist.m_text)
+                    label.set_use_markup(True)
                     label.set_line_wrap(True)
                     label.set_alignment(0.0, 0.5)
                     vbox.pack_start(label, False)
@@ -220,7 +225,9 @@ class ExerciseView(SelectWinBase):
                                 if fieldname in (u'link', u'link-with-filename-tooltip'):
                                     labeltxt = lessonfile.infocache.get(link, 'title')
                                     lbl = gu.ClickableLabel(_no_xgettext(labeltxt))
-                                    if fieldname == u'link-with-filename-tooltip':
+                                    if solfege.app.m_options.debug:
+                                        lbl.set_tooltip_text(u"%s\n%s module" % (link, lessonfile.infocache.get(link, 'module')))
+                                    elif fieldname == u'link-with-filename-tooltip':
                                         lbl.set_tooltip_text(link)
                                     if do_sg:
                                         sizegroups[fieldname].add_widget(lbl)
