@@ -1,6 +1,6 @@
 # vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
-# Copyright (C) 2009  Tom Cato Amundsen
+# Copyright (C) 2009, 2011  Tom Cato Amundsen
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -798,7 +798,7 @@ class Editor(gtk.Window, gu.EditorDialogBase):
         fh.save_file(self.m_filename)
         self.set_not_modified()
         # We do test for solfege.win since it is not available during testing
-        if getattr(solfege, 'win', None):
+        if hasattr(solfege, 'win'):
             solfege.win.load_frontpage()
     def on_show_help(self, *w):
         return
